@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.745';
+our $VERSION = '1.760';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -29,6 +29,24 @@ BEGIN {
     }
 }
 
+END {
+    if ( $? == 255 ) {
+        if( $^O eq 'MSWin32' ) {
+            my $input = Win32::Console->new( Win32::Console::constant( "STD_INPUT_HANDLE",  0 ) );
+            $input->Mode( 0x0001|0x0002|0x0004 );
+            $input->Flush;
+        }
+        elsif ( TERM_READKEY ) {
+            Term::ReadKey::ReadMode( 'restore' );
+        }
+        else {
+            system( "stty sane" );
+        }
+        print "\n", clear_to_end_of_screen;
+        print show_cursor;
+    }
+}
+
 
 sub new {
     my $class = shift;
@@ -61,9 +79,9 @@ sub _valid_options {
         alignment           => '[ 0 1 2 ]',
         color               => '[ 0 1 2 ]',
         include_highlighted => '[ 0 1 2 ]',
+        layout              => '[ 0 1 2 ]',
         page                => '[ 0 1 2 ]',
         search              => '[ 0 1 2 ]',
-        layout              => '[ 0 1 2 3 ]', # '[ 0 1 2 ]'
         keep                => '[ 1-9 ][ 0-9 ]*',
         ll                  => '[ 1-9 ][ 0-9 ]*',
         max_cols            => '[ 1-9 ][ 0-9 ]*',
@@ -71,6 +89,7 @@ sub _valid_options {
         max_width           => '[ 1-9 ][ 0-9 ]*',
         default             => '[ 0-9 ]+',
         pad                 => '[ 0-9 ]+',
+        margin              => 'Array_Int',
         mark                => 'Array_Int',
         meta_items          => 'Array_Int',
         no_spacebar         => 'Array_Int',
@@ -104,12 +123,13 @@ sub _defaults {
         keep                => 5,
         layout              => 1,
         #ll                 => undef,
+        #margin             => undef,
         #mark               => undef,
         #max_cols           => undef,
         #max_height         => undef,
         #max_width          => undef,
-        mouse               => 0,
         #meta_items         => undef,
+        mouse               => 0,
         #no_spacebar        => undef,
         order               => 1,
         pad                 => 2,
@@ -230,17 +250,6 @@ sub __get_key {
 
 sub __modify_options {
     my ( $self ) = @_;
-    ############################## remove this with the next release
-    if ( $self->{layout} == 3 ) {
-        my @caller = caller( 2 );
-        print "@caller[1,2]\n";
-        print "Term::Choose::choose\n";
-        print "Option 'layout': 3 is not a valid value.\n";
-        print "Press ENTER to continue:";
-        my $dummy = <>;
-        $self->{layout} = 2;
-    }
-    ##############################
     if ( defined $self->{max_cols} && $self->{max_cols} == 1 ) {
         $self->{layout} = 2;
     }
@@ -250,12 +259,21 @@ sub __modify_options {
     if ( $self->{page} == 2 && ! $self->{clear_screen} ) {
         $self->{clear_screen} = 1;
     }
-    if ( $self->{max_cols} && $self->{layout} != 0 && $self->{layout} != 2 ) { ##
+    if ( $self->{max_cols} && $self->{layout} == 1 ) {
         $self->{layout} = 0;
     }
     if ( ! defined $self->{prompt} ) {
         $self->{prompt} = defined $self->{wantarray} ? 'Your choice:' : 'Close with ENTER';
     }
+    if ( defined $self->{margin} ) {
+        ( $self->{margin_top}, $self->{margin_right}, $self->{margin_bottom}, $self->{margin_left} ) = @{$self->{margin}};
+        if ( ! defined $self->{tabs_prompt} ) {
+            $self->{tabs_prompt} = [ $self->{margin_left}, $self->{margin_left}, $self->{margin_right} ];
+        }
+        if ( ! defined $self->{tabs_info} ) {
+            $self->{tabs_info} = [ $self->{margin_left}, $self->{margin_left}, $self->{margin_right} ];
+        }
+    }
 }
 
 
@@ -269,6 +287,7 @@ sub choose {
     return $self->__choose( @_ );
 }
 
+
 sub __choose {
     my $self = shift;
     my ( $orig_list_ref, $opt ) = @_;
@@ -332,6 +351,7 @@ sub __choose {
         my ( $new_width, $new_height ) = get_term_size();
         if ( $new_width != $self->{term_width} || $new_height != $self->{term_height} ) {
             if ( $self->{ll} ) {
+                $self->__reset_term( 0 );
                 return -1;
             }
             ( $self->{term_width}, $self->{term_height} ) = ( $new_width, $new_height );
@@ -348,7 +368,7 @@ sub __choose {
         }
         next GET_KEY if $key == NEXT_get_key;
         next GET_KEY if $key == KEY_Tilde;
-        if ( exists $ENV{TC_RESET_AUTO_UP} ) {
+        if ( exists $ENV{TC_RESET_AUTO_UP} && $ENV{TC_RESET_AUTO_UP} == 0 ) {
             if ( $key != LINE_FEED && $key != CARRIAGE_RETURN ) {
                 $ENV{TC_RESET_AUTO_UP} = 1;
             }
@@ -716,39 +736,38 @@ sub __prepare_info_and_prompt_lines {
     if ( $self->{max_width} && $info_w > $self->{max_width} ) { ##
         $info_w = $self->{max_width};
     }
-    my $prompt = '';
+    my @tmp_prompt;
+    if ( $self->{margin_top} ) {
+        push @tmp_prompt, ( '' ) x $self->{margin_top};
+    }
     if ( length $self->{info} ) {
-        my $init   = $self->{tabs_info}[0] ? $self->{tabs_info}[0] : 0;
-        my $subseq = $self->{tabs_info}[1] ? $self->{tabs_info}[1] : 0;
-        $prompt .= line_fold(
-            $self->{info}, $info_w,
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 1 }
+        my $init     = $self->{tabs_info}[0] // 0;
+        my $subseq   = $self->{tabs_info}[1] // 0;
+        my $r_margin = $self->{tabs_info}[2] // 0;
+        push @tmp_prompt, line_fold(
+            $self->{info}, $info_w - $r_margin,
+            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 0 }
         );
     }
     if ( length $self->{prompt} ) {
-        if ( length $prompt ) {
-            $prompt .= "\n";
-        }
-        my $init   = $self->{tabs_prompt}[0] ? $self->{tabs_prompt}[0] : 0;
-        my $subseq = $self->{tabs_prompt}[1] ? $self->{tabs_prompt}[1] : 0;
-        $prompt .= line_fold(
-            $self->{prompt}, $info_w,
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 1 }
+        my $init     = $self->{tabs_prompt}[0] // 0;
+        my $subseq   = $self->{tabs_prompt}[1] // 0;
+        my $r_margin = $self->{tabs_prompt}[2] // 0;
+        push @tmp_prompt, line_fold(
+            $self->{prompt}, $info_w - $r_margin,
+            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 0 }
         );
     }
-    if ( $prompt eq '' ) {
+    if ( length $self->{search_info} ) {
+        push @tmp_prompt, ( $self->{margin_left} ? ' ' x $self->{margin_left} : '' ) . $self->{search_info};
+    }
+    $self->{count_prompt_lines} = @tmp_prompt;
+    if ( ! $self->{count_prompt_lines} ) {
         $self->{prompt_copy} = '';
-        $self->{count_prompt_lines} = 0;
         return;
     }
-    if ( length $self->{search_info} ) {
-        $prompt .= "\n" . $self->{search_info} . ':';
-    }
-    $self->{prompt_copy} = $prompt;
-    $self->{prompt_copy} .= "\n\r";
-    # s/\n/\n\r/g; -> stty 'raw' mode and Term::Readkey 'ultra-raw' mode
-    #                 don't translate newline to carriage return-newline
-    $self->{count_prompt_lines} = $self->{prompt_copy} =~ s/\n/\n\r/g;
+    $self->{prompt_copy} = join( "\n\r", @tmp_prompt ) . "\n\r"; #
+    # \n\r -> stty 'raw' mode and Term::Readkey 'ultra-raw' mode don't translate newline to carriage_return/newline
 }
 
 
@@ -804,9 +823,9 @@ sub __wr_first_screen {
     $self->__current_layout();
     $self->__list_idx2rc();
     $self->__prepare_footer_line();
-    $self->{avail_height_idx} = $self->{avail_height} - 1;
     $self->{first_page_row} = 0;
-    $self->{last_page_row}  = $self->{avail_height_idx} > $#{$self->{rc2idx}} ? $#{$self->{rc2idx}} : $self->{avail_height_idx};
+    my $avail_height_idx = $self->{avail_height} - 1;
+    $self->{last_page_row}  = $avail_height_idx > $#{$self->{rc2idx}} ? $#{$self->{rc2idx}} : $avail_height_idx;
     $self->{i_row}  = 0;
     $self->{i_col}  = 0;
     $self->{pos}    = [ 0, 0 ];
@@ -839,71 +858,77 @@ sub __wr_screen {
     $self->__goto( 0, 0 );
     print "\r" . clear_to_end_of_screen();
     if ( defined $self->{footer_fmt} ) {
-        $self->__goto( $self->{avail_height_idx} + 1, 0 );
         my $pp_line = sprintf $self->{footer_fmt}, int( $self->{first_page_row} / $self->{avail_height} ) + 1;
-        print $pp_line;
-        $self->{i_col} += print_columns( $pp_line );
+        if ( $self->{margin_left} ) {
+            print right( $self->{margin_left} );
+        }
+        print "\n" x ( $self->{avail_height} );
+        print $pp_line . "\r";
+        if ( $self->{margin_bottom} ) {
+            print "\n" x $self->{margin_bottom};
+            print up( $self->{margin_bottom} );
+        }
+        print up( $self->{avail_height} );
     }
+    elsif ( $self->{margin_bottom} ) {
+        my $count = ( $self->{last_page_row} - $self->{first_page_row} ) + $self->{margin_bottom};
+        print "\n" x $count;
+        print up( $count );
+    }
+    if ( $self->{margin_left} ) {
+        print right( $self->{margin_left} ); # left margin after each "\r"
+    }
+    my $pad_str = ' ' x $self->{pad};
     for my $row ( $self->{first_page_row} .. $self->{last_page_row} ) {
-        for my $col ( 0 .. $#{$self->{rc2idx}[$row]} ) {
-            $self->__wr_cell( $row, $col );
+        my $line = $self->__prepare_cell( $row, 0 );
+        if ( $#{$self->{rc2idx}[$row]} ) { #
+            for my $col ( 1 .. $#{$self->{rc2idx}[$row]} ) {
+                $line = $line . $pad_str . $self->__prepare_cell( $row, $col );
+            }
+        }
+        print $line . "\n\r";
+        if ( $self->{margin_left} ) {
+            print right( $self->{margin_left} );
         }
     }
+    print up( $self->{last_page_row} - $self->{first_page_row} + 1 );
+    # relativ cursor pos: 0, 0
     $self->__wr_cell( $self->{pos}[ROW], $self->{pos}[COL] );
 }
 
 
-sub __wr_cell {
+sub __prepare_cell {
     my( $self, $row, $col ) = @_;
     my $is_current_pos = $row == $self->{pos}[ROW] && $col == $self->{pos}[COL];
     my $emphasised = ( $self->{marked}[$row][$col] ? bold_underline() : '' ) . ( $is_current_pos ? reverse_video() : '' );
     my $idx = $self->{rc2idx}[$row][$col];
     if ( $self->{ll} ) {
-        $self->__goto( $row - $self->{first_page_row}, $col * $self->{col_width_plus} );
-        $self->{i_col} = $self->{i_col} + $self->{col_width};
         if ( $self->{color} ) {
             my $str = $self->{list}[$idx];
             if ( $emphasised ) {
                 if ( $is_current_pos && $self->{color} == 1 ) {
-                    # no color for selected cell
+                    # no color for the selected cell if color == 1
                     $str =~ s/(\e\[[\d;]*m)//g;
                 }
                 else {
-                    # keep cell marked after color escapes
+                    # keep marked cells marked after color escapes
                     $str =~ s/(\e\[[\d;]*m)/${1}$emphasised/g;
                 }
                 $str = $emphasised . $str;
             }
-            print $str . normal(); # if \e[
+            return $str . normal();
         }
         else {
             if ( $emphasised ) {
-                print $emphasised . $self->{list}[$idx] . normal();
+                return $emphasised . $self->{list}[$idx] . normal();
             }
             else {
-                print $self->{list}[$idx];
+                return $self->{list}[$idx];
             }
         }
     }
     else {
-        my $str;
-        if ( $self->{current_layout} == -1 ) {
-            my $x = 0;
-            if ( $col > 0 ) {
-                for my $cl ( 0 .. $col - 1 ) {
-                    my $i = $self->{rc2idx}[$row][$cl];
-                    $x += $self->{width_elements}[$i] + $self->{pad};
-                }
-            }
-            $self->__goto( $row - $self->{first_page_row}, $x );
-            $self->{i_col} = $self->{i_col} + $self->{width_elements}[$idx];
-            $str = $self->{list}[$idx];
-        }
-        else {
-            $self->__goto( $row - $self->{first_page_row}, $col * $self->{col_width_plus} );
-            $self->{i_col} = $self->{i_col} + $self->{col_width};
-            $str = $self->__pad_str_to_colwidth( $idx );
-        }
+        my $str = $self->{current_layout} == -1 ? $self->{list}[$idx] : $self->__pad_str_to_colwidth( $idx );
         if ( $self->{color} ) {
             my @color;
             if ( ! $self->{orig_list}[$idx] ) {
@@ -919,12 +944,12 @@ sub __wr_cell {
             }
             if ( $emphasised ) {
                 for ( @color ) {
-                    # keep cell marked after color escapes
+                    # keep marked cells marked after color escapes
                     $_ .= $emphasised;
                 }
                 $str = $emphasised . $str . normal();
                 if ( $is_current_pos && $self->{color} == 1 ) {
-                    # no color for selected cell
+                    # no color for the selected cell if color == 1
                     @color = ();
                     $str =~ s/\x{feff}//g;
                 }
@@ -935,20 +960,40 @@ sub __wr_cell {
                     $str .= normal();
                 }
             }
-            print $str;
+            return $str;
         }
         else {
             if ( $emphasised ) {
-                print $emphasised . $str . normal();
-            }
-            else {
-                print $str;
+                $str = $emphasised . $str . normal();
             }
+            return $str;
         }
     }
 }
 
 
+sub __wr_cell {
+    my( $self, $row, $col ) = @_;
+    my $idx = $self->{rc2idx}[$row][$col];
+    if ( $self->{current_layout} == -1 ) {
+        my $x = 0;
+        if ( $col > 0 ) {
+            for my $cl ( 0 .. $col - 1 ) {
+                my $i = $self->{rc2idx}[$row][$cl];
+                $x += $self->{width_elements}[$i] + $self->{pad};
+            }
+        }
+        $self->__goto( $row - $self->{first_page_row}, $x );
+        $self->{i_col} = $self->{i_col} + $self->{width_elements}[$idx];
+    }
+    else {
+        $self->__goto( $row - $self->{first_page_row}, $col * $self->{col_width_plus} );
+        $self->{i_col} = $self->{i_col} + $self->{col_width};
+    }
+    print $self->__prepare_cell( $row, $col );
+}
+
+
 sub __pad_str_to_colwidth {
     my ( $self, $idx ) = @_;
     if ( $self->{width_elements}[$idx] < $self->{col_width} ) {
@@ -980,11 +1025,10 @@ sub __pad_str_to_colwidth {
 
 sub __goto {
     my ( $self, $newrow, $newcol ) = @_;
-    # up, down, left, right: 1 or greater
+    # requires up, down, left or right to be 1 or greater
     if ( $newrow > $self->{i_row} ) {
-        print "\r\n" x ( $newrow - $self->{i_row} );
+        print down( $newrow - $self->{i_row} );
         $self->{i_row} = $newrow;
-        $self->{i_col} = 0;
     }
     elsif ( $newrow < $self->{i_row} ) {
         print up( $self->{i_row} - $newrow );
@@ -1004,21 +1048,27 @@ sub __goto {
 sub __avail_screen_size {
     my ( $self ) = @_;
     ( $self->{avail_width}, $self->{avail_height} ) = ( $self->{term_width}, $self->{term_height} );
-    if ( $self->{col_width} > $self->{avail_width} && $^O ne 'MSWin32' && $^O ne 'cygwin' ) {
+    if ( $self->{margin_left} ) {
+        $self->{avail_width} -= $self->{margin_left};
+    }
+    if ( $self->{margin_right} ) {
+        $self->{avail_width} -= $self->{margin_right};
+    }
+    if ( $self->{margin_right} || ( $self->{col_width} > $self->{avail_width} && $^O ne 'MSWin32' && $^O ne 'cygwin' ) ) {
         $self->{avail_width} += WIDTH_CURSOR;
-        # + WIDTH_CURSOR: use also the last terminal column if there is only one print-column;
-        #                 with only one print-column the output doesn't get messed up if an item
+        # + WIDTH_CURSOR: use also the last terminal column if there is only one item-column;
+        #                 with only one item-column the output doesn't get messed up if an item
         #                 reaches the right edge of the terminal on a non-MSWin32-OS
     }
-    #if ( $self->{ll} && $self->{ll} > $self->{avail_width} ) {
-    #    return -2;
-    #}
     if ( $self->{max_width} && $self->{avail_width} > $self->{max_width} ) {
         $self->{avail_width} = $self->{max_width};
     }
     if ( $self->{avail_width} < 1 ) {
         $self->{avail_width} = 1;
     }
+    #if ( $self->{ll} && $self->{ll} > $self->{avail_width} ) {
+    #    return -2;
+    #}
     $self->__prepare_info_and_prompt_lines();
     if ( $self->{count_prompt_lines} ) {
         $self->{avail_height} -= $self->{count_prompt_lines};
@@ -1026,6 +1076,9 @@ sub __avail_screen_size {
     if ( $self->{page} ) {
         $self->{avail_height}--;
     }
+    if ( $self->{margin_bottom} ) {
+        $self->{avail_height} -= $self->{margin_bottom};
+    }
     if ( $self->{avail_height} < $self->{keep} ) {
         $self->{avail_height} = $self->{term_height} >= $self->{keep} ? $self->{keep} : $self->{term_height};
     }
@@ -1222,7 +1275,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.745
+Version 1.760
 
 =cut
 
@@ -1366,7 +1419,7 @@ be used instead the C<SpaceBar> key.
 Pressing the C<Ctrl-F> allows one to enter a regular expression so that only the items that match the regular expression
 are displayed. When going back to the unfiltered menu (C<Enter>) the item highlighted in the filtered menu keeps the
 highlighting. Also (in I<list context>) marked items retain there markings. The Perl function C<readline> is used to
-read the regular expression if L<Term::Form> is not available. See option I<search>.
+read the regular expression if L<Term::Form::ReadLine> is not available. See option I<search>.
 
 =head2 Keys to move around
 
@@ -1479,14 +1532,13 @@ Setting this option to C<1> enables the codepage mapping offered by L<Win32::Con
 
 =head3 color
 
-Enable the support for color and text formatting escape sequences.
+Enable the support for ANSI SGR escape sequences.
 
 0 - off (default)
 
-1 - Enables the support for color and text formatting escape sequences except for the current selected element.
+1 - enabled but the current selected element is not colored.
 
-2 - Enables the support for color and text formatting escape sequences including for the current selected element (shown
-in inverted colors).
+2 - enabled
 
 =head3 default
 
@@ -1589,6 +1641,9 @@ Allowed values: 1 or greater
 
 =back
 
+If I<layout> is set to C<0> or C<1> and the unformatted list items fit in one row,  the list items are placed in one row
+without column formatting. This behavior can be disabled by setting I<max_cols>.
+
 =head3 ll
 
 If all elements have the same length, the length can be passed with this option. C<choose> then doesn't calculate the
@@ -1610,10 +1665,33 @@ Allowed values: 1 or greater
 
 (default: undefined)
 
+=head3 margin
+
+The option I<margin> allows one to set a margin on all four sides.
+
+I<margin> expects a reference to an array with four elements in the following order:
+
+- top margin (number of terminal lines)
+
+- right margin (number of terminal columns)
+
+- botton margin (number of terminal lines)
+
+- left margin (number of terminal columns)
+
+I<margin> does not affect the I<info> and I<prompt> string. To add margins to the I<info> and I<prompt> string see
+I<tabs_info> and I<tabs_prompt>.
+
+Allowed values: 0 or greater. Elements beyond the fourth are ignored.
+
+(default: undefined)
+
 =head3 max_cols
 
 Limit the number of columns to I<max_cols>.
 
+I<layout> set to C<2> has always one column.
+
 Allowed values: 1 or greater
 
 (default: undefined)
@@ -1636,7 +1714,7 @@ Allowed values: 1 or greater
 
 If defined, sets the maximal output width to I<max_width> if the terminal width is greater than I<max_width>.
 
-To prevent the "auto-format" to use a width less than I<max_width> set I<layout> to 0.
+To prevent the "auto-format" to use a width less than I<max_width> set I<layout> to C<0>.
 
 Width refers here to the number of print columns.
 
@@ -1683,9 +1761,9 @@ option L<clear_screen>.
 
 =head3 prompt
 
-If I<prompt> is undefined a default prompt-string will be shown.
+If I<prompt> is undefined, a default prompt-string will be shown.
 
-If the I<prompt> value is an empty string ("") no prompt-line will be shown.
+If the I<prompt> value is an empty string (""), no prompt-line will be shown.
 
 default in list and scalar context: C<Your choice:>
 
@@ -1713,33 +1791,39 @@ Expected value: a regex quoted with the C<qr> operator.
 
 =head3 tabs_info
 
-If I<info> lines are folded, the option I<tabs_info> allows one to insert spaces at beginning of the folded lines.
+The option I<tabs_info> allows one to insert spaces at the beginning and the end of I<info> lines.
 
-The option I<tabs_info> expects a reference to an array with one or two elements:
+I<tabs_info> expects a reference to an array with one to three elements:
 
 - the first element (initial tab) sets the number of spaces inserted at beginning of paragraphs
 
-- a second element (subsequent tab) sets the number of spaces inserted at the beginning of all broken lines apart
-from the beginning of paragraphs
+- the second element (subsequent tab) sets the number of spaces inserted at the beginning of all broken lines apart from
+the beginning of paragraphs
 
-Allowed values: 0 or greater. Elements beyond the second are ignored.
+- the third element sets the number of spaces used as a right margin.
 
-(default: undefined)
+Allowed values: 0 or greater. Elements beyond the third are ignored.
+
+default: If I<margin> is defined, the initial tab and the subsequent tab are set to left-I<margin> and the right margin
+is set to right-I<margin>. If I<margin> is not defined, the default is undefined.
 
 =head3 tabs_prompt
 
-If I<prompt> lines are folded, the option I<tabs_prompt> allows one to insert spaces at beginning of the folded lines.
+The option I<tabs_prompt> allows one to insert spaces at the beginning and the end of I<prompt> lines.
 
-The option I<tabs_prompt> expects a reference to an array with one or two elements:
+I<tabs_prompt> expects a reference to an array with one to three elements:
 
 - the first element (initial tab) sets the number of spaces inserted at beginning of paragraphs
 
-- a second element (subsequent tab) sets the number of spaces inserted at the beginning of all broken lines apart
-from the beginning of paragraphs
+- the second element (subsequent tab) sets the number of spaces inserted at the beginning of all broken lines apart from
+the beginning of paragraphs
 
-Allowed values: 0 or greater. Elements beyond the second are ignored.
+- the third element sets the number of spaces used as a right margin.
 
-(default: undefined)
+Allowed values: 0 or greater. Elements beyond the third are ignored.
+
+default: If I<margin> is defined, the initial tab and the subsequent tab are set to left-I<margin> and the right margin
+is set to right-I<margin>. If I<margin> is not defined, the default is undefined.
 
 =head3 undef
 
@@ -1842,16 +1926,17 @@ to a true value, ambiguous width characters are treated as full width.
 
 =head2 Escape sequences
 
-By default C<Term::Choose> uses C<tput> to get the appropriate escape sequences. Setting the environment variable
-C<TC_ANSI_ESCAPES> to a true value allows one to use ANSI escape sequences directly without calling C<tput>.
-
-    BEGIN {
-        $ENV{TC_ANSI_ESCAPES} = 1;
-    }
-    use Term::Choose qw( choose );
+By default C<Term::Choose> uses C<tput> to get the appropriate escape sequences. If the environment variable
+C<TC_ANSI_ESCAPES> is set to a true value, hardcoded ANSI escape sequences are used directly without calling C<tput>.
 
 The escape sequences to enable the I<mouse> mode are always hardcoded.
 
+=head2 Other environment variables
+
+If the environment variable C<TC_RESET_AUTO_UP> existed when calling C<choose>: C<TC_RESET_AUTO_UP> is set to C<0> if
+the C<LINE_FEED>/C<CARRIAGE_RETURN> key was the only key pressed and C<TC_RESET_AUTO_UP> is set ot C<1> if other keys
+than C<LINE_FEED>/C<CARRIAGE_RETURN> were also pressed.
+
 =head2 MSWin32
 
 If the OS is MSWin32 L<Win32::Console> and L<Win32::Console::ANSI> with ANSI escape sequences are used. See also
@@ -1876,7 +1961,7 @@ L<stackoverflow|http://stackoverflow.com> for the help.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2012-2021 Matthäus Kiem.
+Copyright (C) 2012-2023 Matthäus Kiem.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
