@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.745';
+our $VERSION = '1.760';
 
 use Exporter qw( import );
 
@@ -14,7 +14,6 @@ our @EXPORT_OK = qw( table_char_width );
 # test with gnome-terminal - ambiguous characters set to wide
 
 # Control characters, non-characters and surrogates are removed before using this table.
-# However - to have less ranges in table_char_width - surrogates and non-characters return 1.
 
 
 sub table_char_width { [
@@ -155,9 +154,7 @@ sub table_char_width { [
 [   0x5c4,    0x5c5, 0],
 [   0x5c6,    0x5c6, 1],
 [   0x5c7,    0x5c7, 0],
-[   0x5c8,    0x5ff, 1],
-[   0x600,    0x605, 0],
-[   0x606,    0x60f, 1],
+[   0x5c8,    0x60f, 1],
 [   0x610,    0x61a, 0],
 [   0x61b,    0x61b, 1],
 [   0x61c,    0x61c, 0],
@@ -166,8 +163,8 @@ sub table_char_width { [
 [   0x660,    0x66f, 1],
 [   0x670,    0x670, 0],
 [   0x671,    0x6d5, 1],
-[   0x6d6,    0x6dd, 0],
-[   0x6de,    0x6de, 1],
+[   0x6d6,    0x6dc, 0],
+[   0x6dd,    0x6de, 1],
 [   0x6df,    0x6e4, 0],
 [   0x6e5,    0x6e6, 1],
 [   0x6e7,    0x6e8, 0],
@@ -195,8 +192,12 @@ sub table_char_width { [
 [   0x829,    0x82d, 0],
 [   0x82e,    0x858, 1],
 [   0x859,    0x85b, 0],
-[   0x85c,    0x8d2, 1],
-[   0x8d3,    0x902, 0],
+[   0x85c,    0x897, 1],
+[   0x898,    0x89f, 0],
+[   0x8a0,    0x8c9, 1],
+[   0x8ca,    0x8e1, 0],
+[   0x8e2,    0x8e2, 1],
+[   0x8e3,    0x902, 0],
 [   0x903,    0x939, 1],
 [   0x93a,    0x93a, 0],
 [   0x93b,    0x93b, 1],
@@ -275,7 +276,9 @@ sub table_char_width { [
 [   0xc00,    0xc00, 0],
 [   0xc01,    0xc03, 1],
 [   0xc04,    0xc04, 0],
-[   0xc05,    0xc3d, 1],
+[   0xc05,    0xc3b, 1],
+[   0xc3c,    0xc3c, 0],
+[   0xc3d,    0xc3d, 1],
 [   0xc3e,    0xc40, 0],
 [   0xc41,    0xc45, 1],
 [   0xc46,    0xc48, 0],
@@ -326,8 +329,8 @@ sub table_char_width { [
 [   0xeb2,    0xeb3, 1],
 [   0xeb4,    0xebc, 0],
 [   0xebd,    0xec7, 1],
-[   0xec8,    0xecd, 0],
-[   0xece,    0xf17, 1],
+[   0xec8,    0xece, 0],
+[   0xecf,    0xf17, 1],
 [   0xf18,    0xf19, 0],
 [   0xf1a,    0xf34, 1],
 [   0xf35,    0xf35, 0],
@@ -377,8 +380,8 @@ sub table_char_width { [
 [  0x1360,   0x1711, 1],
 [  0x1712,   0x1714, 0],
 [  0x1715,   0x1731, 1],
-[  0x1732,   0x1734, 0],
-[  0x1735,   0x1751, 1],
+[  0x1732,   0x1733, 0],
+[  0x1734,   0x1751, 1],
 [  0x1752,   0x1753, 0],
 [  0x1754,   0x1771, 1],
 [  0x1772,   0x1773, 0],
@@ -393,8 +396,8 @@ sub table_char_width { [
 [  0x17d4,   0x17dc, 1],
 [  0x17dd,   0x17dd, 0],
 [  0x17de,   0x180a, 1],
-[  0x180b,   0x180e, 0],
-[  0x180f,   0x1884, 1],
+[  0x180b,   0x180f, 0],
+[  0x1810,   0x1884, 1],
 [  0x1885,   0x1886, 0],
 [  0x1887,   0x18a8, 1],
 [  0x18a9,   0x18a9, 0],
@@ -425,8 +428,8 @@ sub table_char_width { [
 [  0x1a7d,   0x1a7e, 1],
 [  0x1a7f,   0x1a7f, 0],
 [  0x1a80,   0x1aaf, 1],
-[  0x1ab0,   0x1ac0, 0],
-[  0x1ac1,   0x1aff, 1],
+[  0x1ab0,   0x1ace, 0],
+[  0x1acf,   0x1aff, 1],
 [  0x1b00,   0x1b03, 0],
 [  0x1b04,   0x1b33, 1],
 [  0x1b34,   0x1b34, 0],
@@ -471,9 +474,7 @@ sub table_char_width { [
 [  0x1cf5,   0x1cf7, 1],
 [  0x1cf8,   0x1cf9, 0],
 [  0x1cfa,   0x1dbf, 1],
-[  0x1dc0,   0x1df9, 0],
-[  0x1dfa,   0x1dfa, 1],
-[  0x1dfb,   0x1dff, 0],
+[  0x1dc0,   0x1dff, 0],
 [  0x1e00,   0x200a, 1],
 [  0x200b,   0x200f, 0],
 [  0x2010,   0x2010, 2],
@@ -838,7 +839,8 @@ sub table_char_width { [
 [  0xabed,   0xabed, 0],
 [  0xabee,   0xabff, 1],
 [  0xac00,   0xd7a3, 2],
-[  0xd7a4,   0xdfff, 1],
+[  0xd7a4,   0xd7ff, 1],
+#[  0xd800,   0xdfff, -1],
 [  0xe000,   0xfaff, 2],
 [  0xfb00,   0xfb1d, 1],
 [  0xfb1e,   0xfb1e, 0],
@@ -884,13 +886,21 @@ sub table_char_width { [
 [ 0x10d24,  0x10d27, 0],
 [ 0x10d28,  0x10eaa, 1],
 [ 0x10eab,  0x10eac, 0],
-[ 0x10ead,  0x10f45, 1],
+[ 0x10ead,  0x10efc, 1],
+[ 0x10efd,  0x10eff, 0],
+[ 0x10f00,  0x10f45, 1],
 [ 0x10f46,  0x10f50, 0],
-[ 0x10f51,  0x11000, 1],
+[ 0x10f51,  0x10f81, 1],
+[ 0x10f82,  0x10f85, 0],
+[ 0x10f86,  0x11000, 1],
 [ 0x11001,  0x11001, 0],
 [ 0x11002,  0x11037, 1],
 [ 0x11038,  0x11046, 0],
-[ 0x11047,  0x1107e, 1],
+[ 0x11047,  0x1106f, 1],
+[ 0x11070,  0x11070, 0],
+[ 0x11071,  0x11072, 1],
+[ 0x11073,  0x11074, 0],
+[ 0x11075,  0x1107e, 1],
 [ 0x1107f,  0x11081, 0],
 [ 0x11082,  0x110b2, 1],
 [ 0x110b3,  0x110b6, 0],
@@ -898,7 +908,9 @@ sub table_char_width { [
 [ 0x110b9,  0x110ba, 0],
 [ 0x110bb,  0x110bc, 1],
 [ 0x110bd,  0x110bd, 0],
-[ 0x110be,  0x110cc, 1],
+[ 0x110be,  0x110c1, 1],
+[ 0x110c2,  0x110c2, 0],
+[ 0x110c3,  0x110cc, 1],
 [ 0x110cd,  0x110cd, 0],
 [ 0x110ce,  0x110ff, 1],
 [ 0x11100,  0x11102, 0],
@@ -924,7 +936,9 @@ sub table_char_width { [
 [ 0x11236,  0x11237, 0],
 [ 0x11238,  0x1123d, 1],
 [ 0x1123e,  0x1123e, 0],
-[ 0x1123f,  0x112de, 1],
+[ 0x1123f,  0x11240, 1],
+[ 0x11241,  0x11241, 0],
+[ 0x11242,  0x112de, 1],
 [ 0x112df,  0x112df, 0],
 [ 0x112e0,  0x112e2, 1],
 [ 0x112e3,  0x112ea, 0],
@@ -1046,9 +1060,19 @@ sub table_char_width { [
 [ 0x11d97,  0x11d97, 0],
 [ 0x11d98,  0x11ef2, 1],
 [ 0x11ef3,  0x11ef4, 0],
-[ 0x11ef5,  0x1342f, 1],
-[ 0x13430,  0x13438, 0],
-[ 0x13439,  0x16aef, 1],
+[ 0x11ef5,  0x11eff, 1],
+[ 0x11f00,  0x11f01, 0],
+[ 0x11f02,  0x11f35, 1],
+[ 0x11f36,  0x11f3a, 0],
+[ 0x11f3b,  0x11f3f, 1],
+[ 0x11f40,  0x11f40, 0],
+[ 0x11f41,  0x11f41, 1],
+[ 0x11f42,  0x11f42, 0],
+[ 0x11f43,  0x1342f, 1],
+[ 0x13430,  0x13440, 0],
+[ 0x13441,  0x13446, 1],
+[ 0x13447,  0x13455, 0],
+[ 0x13456,  0x16aef, 1],
 [ 0x16af0,  0x16af4, 0],
 [ 0x16af5,  0x16b2f, 1],
 [ 0x16b30,  0x16b36, 0],
@@ -1067,11 +1091,21 @@ sub table_char_width { [
 [ 0x18800,  0x18cd5, 2],
 [ 0x18cd6,  0x18cff, 1],
 [ 0x18d00,  0x18d08, 2],
-[ 0x18d09,  0x1afff, 1],
-[ 0x1b000,  0x1b11e, 2],
-[ 0x1b11f,  0x1b14f, 1],
+[ 0x18d09,  0x1afef, 1],
+[ 0x1aff0,  0x1aff3, 2],
+[ 0x1aff4,  0x1aff4, 1],
+[ 0x1aff5,  0x1affb, 2],
+[ 0x1affc,  0x1affc, 1],
+[ 0x1affd,  0x1affe, 2],
+[ 0x1afff,  0x1afff, 1],
+[ 0x1b000,  0x1b122, 2],
+[ 0x1b123,  0x1b131, 1],
+[ 0x1b132,  0x1b132, 2],
+[ 0x1b133,  0x1b14f, 1],
 [ 0x1b150,  0x1b152, 2],
-[ 0x1b153,  0x1b163, 1],
+[ 0x1b153,  0x1b154, 1],
+[ 0x1b155,  0x1b155, 2],
+[ 0x1b156,  0x1b163, 1],
 [ 0x1b164,  0x1b167, 2],
 [ 0x1b168,  0x1b16f, 1],
 [ 0x1b170,  0x1b2fb, 2],
@@ -1079,7 +1113,11 @@ sub table_char_width { [
 [ 0x1bc9d,  0x1bc9e, 0],
 [ 0x1bc9f,  0x1bc9f, 1],
 [ 0x1bca0,  0x1bca3, 0],
-[ 0x1bca4,  0x1d166, 1],
+[ 0x1bca4,  0x1ceff, 1],
+[ 0x1cf00,  0x1cf2d, 0],
+[ 0x1cf2e,  0x1cf2f, 1],
+[ 0x1cf30,  0x1cf46, 0],
+[ 0x1cf47,  0x1d166, 1],
 [ 0x1d167,  0x1d169, 0],
 [ 0x1d16a,  0x1d172, 1],
 [ 0x1d173,  0x1d182, 0],
@@ -1111,11 +1149,17 @@ sub table_char_width { [
 [ 0x1e023,  0x1e024, 0],
 [ 0x1e025,  0x1e025, 1],
 [ 0x1e026,  0x1e02a, 0],
-[ 0x1e02b,  0x1e12f, 1],
+[ 0x1e02b,  0x1e08e, 1],
+[ 0x1e08f,  0x1e08f, 0],
+[ 0x1e090,  0x1e12f, 1],
 [ 0x1e130,  0x1e136, 0],
-[ 0x1e137,  0x1e2eb, 1],
+[ 0x1e137,  0x1e2ad, 1],
+[ 0x1e2ae,  0x1e2ae, 0],
+[ 0x1e2af,  0x1e2eb, 1],
 [ 0x1e2ec,  0x1e2ef, 0],
-[ 0x1e2f0,  0x1e8cf, 1],
+[ 0x1e2f0,  0x1e4eb, 1],
+[ 0x1e4ec,  0x1e4ef, 0],
+[ 0x1e4f0,  0x1e8cf, 1],
 [ 0x1e8d0,  0x1e8d6, 0],
 [ 0x1e8d7,  0x1e943, 1],
 [ 0x1e944,  0x1e94a, 0],
@@ -1185,37 +1229,37 @@ sub table_char_width { [
 [ 0x1f6d0,  0x1f6d2, 2],
 [ 0x1f6d3,  0x1f6d4, 1],
 [ 0x1f6d5,  0x1f6d7, 2],
-[ 0x1f6d8,  0x1f6ea, 1],
+[ 0x1f6d8,  0x1f6db, 1],
+[ 0x1f6dc,  0x1f6df, 2],
+[ 0x1f6e0,  0x1f6ea, 1],
 [ 0x1f6eb,  0x1f6ec, 2],
 [ 0x1f6ed,  0x1f6f3, 1],
 [ 0x1f6f4,  0x1f6fc, 2],
 [ 0x1f6fd,  0x1f7df, 1],
 [ 0x1f7e0,  0x1f7eb, 2],
-[ 0x1f7ec,  0x1f90b, 1],
+[ 0x1f7ec,  0x1f7ef, 1],
+[ 0x1f7f0,  0x1f7f0, 2],
+[ 0x1f7f1,  0x1f90b, 1],
 [ 0x1f90c,  0x1f93a, 2],
 [ 0x1f93b,  0x1f93b, 1],
 [ 0x1f93c,  0x1f945, 2],
 [ 0x1f946,  0x1f946, 1],
-[ 0x1f947,  0x1f978, 2],
-[ 0x1f979,  0x1f979, 1],
-[ 0x1f97a,  0x1f9cb, 2],
-[ 0x1f9cc,  0x1f9cc, 1],
-[ 0x1f9cd,  0x1f9ff, 2],
+[ 0x1f947,  0x1f9ff, 2],
 [ 0x1fa00,  0x1fa6f, 1],
-[ 0x1fa70,  0x1fa74, 2],
-[ 0x1fa75,  0x1fa77, 1],
-[ 0x1fa78,  0x1fa7a, 2],
-[ 0x1fa7b,  0x1fa7f, 1],
-[ 0x1fa80,  0x1fa86, 2],
-[ 0x1fa87,  0x1fa8f, 1],
-[ 0x1fa90,  0x1faa8, 2],
-[ 0x1faa9,  0x1faaf, 1],
-[ 0x1fab0,  0x1fab6, 2],
-[ 0x1fab7,  0x1fabf, 1],
-[ 0x1fac0,  0x1fac2, 2],
-[ 0x1fac3,  0x1facf, 1],
-[ 0x1fad0,  0x1fad6, 2],
-[ 0x1fad7,  0x1ffff, 1],
+[ 0x1fa70,  0x1fa7c, 2],
+[ 0x1fa7d,  0x1fa7f, 1],
+[ 0x1fa80,  0x1fa88, 2],
+[ 0x1fa89,  0x1fa8f, 1],
+[ 0x1fa90,  0x1fabd, 2],
+[ 0x1fabe,  0x1fabe, 1],
+[ 0x1fabf,  0x1fac5, 2],
+[ 0x1fac6,  0x1facd, 1],
+[ 0x1face,  0x1fadb, 2],
+[ 0x1fadc,  0x1fadf, 1],
+[ 0x1fae0,  0x1fae8, 2],
+[ 0x1fae9,  0x1faef, 1],
+[ 0x1faf0,  0x1faf8, 2],
+[ 0x1faf9,  0x1ffff, 1],
 [ 0x20000,  0x2fffd, 2],
 [ 0x2fffe,  0x2ffff, 1],
 [ 0x30000,  0x3fffd, 2],
